<?php
/**
 * @package		Joomla.Site
 * @subpackage	mod_articles_categories
 * @copyright	Copyright (C) 2005 - 2012 Open Source Matters, Inc. All rights reserved.
 * @license		GNU General Public License version 2 or later; see LICENSE.txt
 */

// no direct access
defined('_JEXEC') or die;

require_once JPATH_SITE.'/components/com_content/helpers/route.php';
jimport('joomla.application.categories');
jimport('joomla.application.component.model');
JModel::addIncludePath(JPATH_SITE.'/components/com_content/models', 'ContentModel');

// usort() comparison function for Person objects
function modArtCats25SortByTitle($a, $b) {
    return $a->title == $b->title ? 0 : ( $a->title > $b->title ) ? 1 : -1;
}

abstract class modArtCats25Helper
{
	public static function getList(&$params, &$module = null)
	{
		$options = array();
		if ($params->get('show_empty_categories', 1) || $params->get('show_category_count', 0))
		{
			$options['countItems'] = 1;
		}
		$categories = JCategories::getInstance('Content', $options);
		$category = $categories->get($params->get('parent', 'root'));

		if (!empty($module))
		{
			if ($params->get('title_mode', 1))
			{
				$categoryLink = JRoute::_(ContentHelperRoute::getCategoryRoute($category->id));
				$module->title = '<a href="' . $categoryLink . '">' . $category->title . '</a>';
			}
		}

		if ($category != null)
		{
			$level = $category->level;
			$items = $category->getChildren();

			$isLeaf = false;
			if (empty($items)) {
				$isLeaf = true;
				$showChildren = (bool) $params->get('show_children', 0);
				if (!$showChildren)
				{
					$items = $category->getParent()->getChildren();
				}
			}

			JArrayHelper::sortObjects($items, $params->get('ordering', 'title'),
											  (int) $params->get('ordering_direction', '1'),
											  (bool) $params->get('ordering_case', true),
											  (bool) $params->get('ordering_locale', false));
			//usort($items, 'modArtCats25SortByTitle');
			if($params->get('count', 0) > 0 && count($items) > $params->get('count', 0))
			{
				$items = array_slice($items, 0, $params->get('count', 0));
			}

			$listMode = $params->get('list_mode', 'combined');

			if ($listMode === 'combined' || $listMode === 'articles')
			{
				$itemsArticles = self::getArticleList($params);

				if (!empty($module))
				{
					if ($isLeaf && (count($itemsArticles) === 0))
					{
						if ($params->get('title_mode', 1))
						{
							$categoryLink = JRoute::_(ContentHelperRoute::getCategoryRoute($category->getParent()->id));
							if ($category->getParent()->id === 'root')
							{
								$module->title = '<a href="' . $categoryLink . '">' . 'Home' . '</a>';
							}
							else
							{
								$module->title = '<a href="' . $categoryLink . '">' . $category->getParent()->title . '</a>';
							}
						}
					}
				}

				// Access filter
				$access = !$params->get('show_noauth');
				$authorised = JAccess::getAuthorisedViewLevels(JFactory::getUser()->get('id'));

				// Display options
				$show_date = $params->get('show_date', 0);
				$show_date_field = $params->get('show_date_field', 'created');
				$show_date_format = $params->get('show_date_format', 'Y-m-d H:i:s');

				foreach($itemsArticles as &$article) {
					$article->level = $level + 1;
					$article->created_time =& $article->created;
					$article->modified_time =& $article->modified;

					$article->slug = $article->id.':'.$article->alias;
					$article->catslug = $article->catid ? $article->catid .':'.$article->category_alias : $article->catid;

					if ($access || in_array($article->access, $authorised))
					{
						// We know that user has the privilege to view the article
						$article->link = JRoute::_(ContentHelperRoute::getArticleRoute($article->slug, $article->catslug));
					}
					else
					{
						// Angie Fixed Routing
						$app	= JFactory::getApplication();
						$menu	= $app->getMenu();
						$menuitems	= $menu->getItems('link', 'index.php?option=com_users&view=login');

						if(isset($menuitems[0]))
						{
							$Itemid = $menuitems[0]->id;
						}
						elseif (JRequest::getInt('Itemid') > 0)
						{
							//use Itemid from requesting page only if there is no existing menu
							$Itemid = JRequest::getInt('Itemid');
						}

						$article->link = JRoute::_('index.php?option=com_users&view=login&Itemid='.$Itemid);
					}

					$article->displayDate = '';
					if ($show_date) {
						$article->displayDate = JHTML::_('date', $article->$show_date_field, $show_date_format);
					}
				}

				//JArrayHelper::sortObjects($itemsArticles, $params->get('article_ordering', 'title'),
					//						  (int) $params->get('article_ordering_direction', '1'),
						//					  (bool) $params->get('article_ordering_case', true),
							//				  (bool) $params->get('article_ordering_locale', false));

				if (($isLeaf && count($itemsArticles)) || $listMode === 'articles') {
					$items = $itemsArticles;
				} else {
					$items = array_merge($items, $itemsArticles);
				}
			}


			//usort($items, 'modArtCats25SortByTitle');

			return $items;
		}
	}

	public static function getArticleList(&$params)
	{
		// Get an instance of the generic articles model
		$articles = JModel::getInstance('Articles', 'ContentModel', array('ignore_request' => true));

		// Set application parameters in model
		$app = JFactory::getApplication();
		$appParams = $app->getParams();
		$articles->setState('params', $appParams);

		// Set the filters based on the module params
		$articles->setState('list.start', 0);
		$articles->setState('list.limit', (int) $params->get('count', 0));
		$articles->setState('filter.published', 1);

		// Access filter
		$access = !$params->get('show_noauth');
		$authorised = JAccess::getAuthorisedViewLevels(JFactory::getUser()->get('id'));
		$articles->setState('filter.access', $access);

		$articles->setState('filter.category_id.include', true);

		$articles->setState('filter.category_id', $params->get('parent', 1));

		$listMode = $params->get('list_mode', 'combined');
		if ($listMode === 'articles')
		{
			$catids = (array) $params->get('parent', 1);
			// Category filter
			if ($params->get('show_child_category_articles', 0) && (int) $params->get('maxlevel', 0) > 0) {
				// Get an instance of the generic categories model
				$categories = JModel::getInstance('Categories', 'ContentModel', array('ignore_request' => true));
				$categories->setState('params', $appParams);
				$levels = $params->get('maxlevel', 1) ? $params->get('maxlevel', 1) : 9999;
				$categories->setState('filter.get_children', $levels);
				$categories->setState('filter.published', 1);
				$categories->setState('filter.access', $access);
				$additional_catids = array();

				foreach($catids as $catid)
				{
					$categories->setState('filter.parentId', $catid);
					$recursive = true;
					$items = $categories->getItems($recursive);

					if ($items)
					{
						foreach($items as $category)
						{
							$condition = (($category->level - $categories->getParent()->level) <= $levels);
							if ($condition) {
								$additional_catids[] = $category->id;
							}

						}
					}
				}

				$catids = array_unique(array_merge($catids, $additional_catids));
			}

			$articles->setState('filter.category_id', $catids);
		}

		// Ordering
		$articles->setState('list.ordering', $params->get('article_ordering', 'a.ordering'));
		$articles->setState('list.direction', $params->get('article_ordering_direction', 'ASC'));

		// New Parameters
		$articles->setState('filter.featured', $params->get('show_front', 'show'));

		// Filter by language
		$articles->setState('filter.language',$app->getLanguageFilter());

		$itemsArticles = $articles->getItems();

		return (array) $itemsArticles;
	}

}
